import{dt as n}from"./index-2-qFLlQP.js";import{_ as m}from"./MediaTitle.vue_vue_type_script_setup_true_lang-C59zAxW0.js";import{bx as r,E as c,c as t,d as s,z as l,e as d,q as p,u as a}from"./vendor-other-CSX7WseZ.js";import"./vendor-primevue-B6rcS73U.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";const f={class:"flex flex-col items-center gap-1"},_={class:"flex items-center text-xs text-zinc-400"},u={key:0},z=r({__name:"MediaImageBottom",props:{asset:{}},setup(o){const i=c(()=>n(o.asset.name).filename);return(e,h)=>(s(),t("div",f,[l(m,{"file-name":i.value},null,8,["file-name"]),d("div",_,[e.asset.dimensions?(s(),t("span",u,a(e.asset.dimensions?.width)+"x"+a(e.asset.dimensions?.height),1)):p("",!0)])]))}});export{z as default};
//# sourceMappingURL=MediaImageBottom-OWiMf_6W.js.map
