import{bx as l,i as u,c as o,d as s,q as i,e as r,by as a,F as m,A as g,u as p,I as n,s as c,p as f}from"./vendor-other-CSX7WseZ.js";import{c as w}from"./index-2-qFLlQP.js";const y={class:"grid grid-cols-subgrid min-w-0 justify-between gap-1 text-node-component-slot-text"},b={key:0,class:"truncate content-center-safe"},h={class:"relative min-w-0 flex-1"},_=l({__name:"WidgetLayoutField",props:{widget:{}},setup(v){const d=u("hideLayoutField",!1);return(t,e)=>(s(),o("div",y,[a(d)?i("",!0):(s(),o("div",b,[t.widget.name?(s(),o(m,{key:0},[g(p(t.widget.label||t.widget.name),1)],64)):i("",!0)])),r("div",h,[r("div",{class:c(a(w)("cursor-default min-w-0 rounded-lg focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all",t.widget.borderStyle)),onPointerdown:e[0]||(e[0]=n(()=>{},["stop"])),onPointermove:e[1]||(e[1]=n(()=>{},["stop"])),onPointerup:e[2]||(e[2]=n(()=>{},["stop"]))},[f(t.$slots,"default")],34)])]))}});export{_};
//# sourceMappingURL=WidgetLayoutField.vue_vue_type_script_setup_true_lang-Dps42A-g.js.map
