import{e as i}from"./vendor-primevue-B6rcS73U.js";import{c as d}from"./index-2-qFLlQP.js";import{f as p,I as u}from"./widgetPropFilter-CygYoMQt.js";import{W as n}from"./index-_AAd9eTu.js";import{_ as f}from"./WidgetLayoutField.vue_vue_type_script_setup_true_lang-Dps42A-g.js";import{bx as c,cM as g,cN as w,E as V,j as x,d as P,k as _,z as b,by as e,m as C}from"./vendor-other-CSX7WseZ.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";const z=c({__name:"WidgetInputText",props:g({widget:{}},{modelValue:{default:""},modelModifiers:{}}),emits:["update:modelValue"],setup(t){const l=t,a=w(t,"modelValue"),r=V(()=>p(l.widget.options,u));return(o,s)=>(P(),x(f,{widget:o.widget},{default:_(()=>[b(e(i),C({modelValue:a.value,"onUpdate:modelValue":s[0]||(s[0]=m=>a.value=m)},r.value,{class:e(d)(e(n),"w-full text-xs py-2 px-4"),"aria-label":o.widget.name,size:"small",pt:{root:"truncate min-w-[4ch]"}}),null,16,["modelValue","class","aria-label"])]),_:1},8,["widget"]))}});export{z as default};
//# sourceMappingURL=WidgetInputText-BRV8PzCv.js.map
