import{dt as i,dm as m}from"./index-2-qFLlQP.js";import{_ as n}from"./MediaTitle.vue_vue_type_script_setup_true_lang-C59zAxW0.js";import{bx as r,E as l,c as t,d as s,z as c,q as p,e as f,u as d,by as u}from"./vendor-other-CSX7WseZ.js";import"./vendor-primevue-B6rcS73U.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";const _={class:"flex flex-col items-center gap-1"},x={key:0,class:"flex items-center gap-2 text-xs text-zinc-400"},b=r({__name:"MediaAudioBottom",props:{asset:{}},setup(a){const o=l(()=>i(a.asset.name).filename);return(e,z)=>(s(),t("div",_,[c(n,{"file-name":o.value},null,8,["file-name"]),e.asset.size?(s(),t("div",x,[f("span",null,d(u(m)(e.asset.size)),1)])):p("",!0)]))}});export{b as default};
//# sourceMappingURL=MediaAudioBottom-CWxtJ5vP.js.map
