import{c as o}from"./index-2-qFLlQP.js";const e=o(["not-disabled:bg-component-node-widget-background","not-disabled:text-component-node-foreground","border-none","rounded-lg"]);export{e as W};
//# sourceMappingURL=index-_AAd9eTu.js.map
