var t=Object.defineProperty;var s=(e,a)=>t(e,"name",{value:a,configurable:!0});import{a8 as c}from"./vendor-primevue-B6rcS73U.js";import{bx as i,r as n,E as p,j as u,d as m,by as f}from"./vendor-other-CSX7WseZ.js";const g=i({__name:"UserAvatar",props:{photoUrl:{},ariaLabel:{}},setup(e){const a=n(!1),l=s(()=>{a.value=!0},"handleImageError"),o=p(()=>e.photoUrl&&!a.value);return(r,v)=>(m(),u(f(c),{class:"bg-interface-panel-selected-surface",image:r.photoUrl??void 0,icon:o.value?void 0:"icon-[lucide--user]","pt:icon:class":{"size-4":!o.value},shape:"circle","aria-label":r.ariaLabel??r.$t("auth.login.userAvatar"),onError:l},null,8,["image","icon","pt:icon:class","aria-label"]))}});export{g as _};
//# sourceMappingURL=UserAvatar.vue_vue_type_script_setup_true_lang-ZL9faEyg.js.map
