[data-v-06049058] .p-datatable-tbody>tr>td{padding:calc(var(--spacing,.25rem)*1);min-height:2rem}:is([data-v-06049058] .p-datatable-row-selected .actions,[data-v-06049058] .p-datatable-selectable-row:hover .actions){visibility:visible}
