import{_ as o}from"./Load3D.vue_vue_type_script_setup_true_lang-BtNou66j.js";import"./vendor-other-CSX7WseZ.js";import"./vendor-primevue-B6rcS73U.js";import"./index-2-qFLlQP.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";export{o as default};
//# sourceMappingURL=Load3D-BplYUML3.js.map
