var s=Object.defineProperty;var r=(t,e)=>s(t,"name",{value:e,configurable:!0});import{d as a}from"./index-2-qFLlQP.js";import{c as l,d,e as o,u as i}from"./vendor-other-CSX7WseZ.js";import"./vendor-primevue-B6rcS73U.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";const c={},n={class:"relative size-full overflow-hidden rounded"},u={class:"flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105"},m={class:"text-sm text-base-foreground"};function p(t,e){return d(),l("div",n,[o("div",u,[e[0]||(e[0]=o("i",{class:"icon-[lucide--box] text-3xl text-muted-foreground"},null,-1)),o("span",m,i(t.$t("assetBrowser.media.threeDModelPlaceholder")),1)])])}r(p,"_sfc_render");const k=a(c,[["render",p]]);export{k as default};
//# sourceMappingURL=Media3DTop-CIsQ4Ccc.js.map
