const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./ValueControlPopover-CgyNfIEw.js","./vendor-primevue-B6rcS73U.js","./vendor-other-CSX7WseZ.js","./vendor-other-DYX1NpEr.css","./index-2-qFLlQP.js","./vendor-vue-CXt3ZZQ3.js","./vendor-xterm-CWYFmgbN.js","./vendor-xterm-xj0gfbX3.css","./vendor-three-BKWXAgVe.js","./vendor-tiptap-BkFTmTb3.js","./index-571Fkv7y.css"])))=>i.map(i=>d[i]);
var v=Object.defineProperty;var d=(o,s)=>v(o,"name",{value:s,configurable:!0});import{_ as V}from"./vendor-primevue-B6rcS73U.js";import{bx as _,cM as w,cN as x,r as u,E as C,w as b,c as M,d as c,j as P,z as m,t as h,m as k,k as p,I as y,e as B,s as z,by as E,dt as W}from"./vendor-other-CSX7WseZ.js";import{_ as I}from"./index-2-qFLlQP.js";const N={class:"relative grid grid-cols-subgrid"},j=_({__name:"WidgetWithControl",props:w({widget:{},component:{}},{modelValue:{},modelModifiers:{}}),emits:["update:modelValue"],setup(o){const s=W(()=>V(()=>import("./ValueControlPopover-CgyNfIEw.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10]),import.meta.url)),n=o,r=x(o,"modelValue"),i=u(),t=u(n.widget.controlWidget.value),f=C(()=>{switch(t.value){case"increment":return"pi pi-plus";case"decrement":return"pi pi-minus";case"fixed":return"icon-[lucide--pencil-off]";default:return"icon-[lucide--shuffle]"}});b(t,n.widget.controlWidget.update);const g=d(e=>{i.value.toggle(e)},"togglePopover");return(e,l)=>(c(),M("div",N,[(c(),P(h(e.component),k(e.$attrs,{modelValue:r.value,"onUpdate:modelValue":l[0]||(l[0]=a=>r.value=a),widget:e.widget}),{default:p(()=>[m(I,{variant:"textonly",size:"sm",class:"h-4 w-7 self-center rounded-xl bg-blue-100/30 p-0",onPointerdown:y(g,["stop","prevent"])},{default:p(()=>[B("i",{class:z(`${f.value} text-blue-100 text-xs size-3.5`)},null,2)]),_:1})]),_:1},16,["modelValue","widget"])),m(E(s),{ref_key:"popover",ref:i,modelValue:t.value,"onUpdate:modelValue":l[1]||(l[1]=a=>t.value=a)},null,8,["modelValue"])]))}});export{j as _};
//# sourceMappingURL=WidgetWithControl.vue_vue_type_script_setup_true_lang-COy_p9Eh.js.map
