import{aa as c}from"./vendor-primevue-B6rcS73U.js";import{bx as i,cM as n,cN as p,E as a,c as u,d as m,e as f,z as g,by as h}from"./vendor-other-CSX7WseZ.js";const y={class:"flex flex-col gap-1"},w={class:"max-h-[48rem] rounded border p-4"},A=i({__name:"WidgetChart",props:n({widget:{}},{modelValue:{required:!0},modelModifiers:{}}),emits:["update:modelValue"],setup(r){const s=p(r,"modelValue"),o=r,t=a(()=>o.widget.options?.type??"line"),l=a(()=>s.value||{labels:[],datasets:[]}),d=a(()=>({responsive:!0,maintainAspectRatio:!1,plugins:{legend:{labels:{color:"#FFF",usePointStyle:!0,pointStyle:"circle"}}},scales:{x:{ticks:{color:"#9FA2BD"},grid:{display:!0,color:"#9FA2BD",drawTicks:!1,drawOnChartArea:!0,drawBorder:!1},border:{display:!0,color:"#9FA2BD"}},y:{ticks:{color:"#9FA2BD"},grid:{display:!1,drawTicks:!1,drawOnChartArea:!1,drawBorder:!1},border:{display:!0,color:"#9FA2BD"}}}}));return(e,B)=>(m(),u("div",y,[f("div",w,[g(h(c),{type:t.value,data:l.value,options:d.value,"aria-label":`${e.widget.name||e.$t("g.chart")} - ${t.value} ${e.$t("g.chartLowercase")}`},null,8,["type","data","options","aria-label"])])]))}});export{A as default};
//# sourceMappingURL=WidgetChart-DhqaPBaM.js.map
