var o=Object.defineProperty;var a=(t,r)=>o(t,"name",{value:r,configurable:!0});import{a as i,q as s}from"./index-2-qFLlQP.js";function l(t){if(isNaN(t)||t===0)return"0:00";const r=Math.floor(t/60),n=Math.floor(t%60);return`${r}:${n.toString().padStart(2,"0")}`}a(l,"formatTime");function c(t,r="input"){const[n,e]=f(t);return i.apiURL(u(n,e,r))}a(c,"getAudioUrlFromPath");function u(t,r,n="input"){return`/view?${["filename="+encodeURIComponent(r),"type="+n,"subfolder="+t,s.getRandParam().substring(1)].join("&")}`}a(u,"getResourceURL");function f(t){const r=t.lastIndexOf("/");return r===-1?["",t]:[t.substring(0,r),t.substring(r+1)]}a(f,"splitFilePath");export{c as a,l as f,u as g,f as s};
//# sourceMappingURL=audioUtils-DlA-QHPJ.js.map
