var o=Object.defineProperty;var i=(s,a)=>o(s,"name",{value:a,configurable:!0});const t=["style","class","dt","pt","ptOptions","unstyled"],r=[...t,"inputClass","inputStyle"],c=[...t,"panelClass","panelStyle","overlayClass"],D=[...t,"thumbnailsPosition","verticalThumbnailViewPortHeight","indicatorsPosition","maskClass","containerStyle","containerClass","galleriaClass"],E=[...t,"badgeClass"];function C(s,a){if(!s)return{};const e={};for(const[n,l]of Object.entries(s))a.includes(n)||(e[n]=l);return e}i(C,"filterWidgetProps");export{E as B,D as G,r as I,c as P,t as S,C as f};
//# sourceMappingURL=widgetPropFilter-CygYoMQt.js.map
