var c=Object.defineProperty;var a=(t,e)=>c(t,"name",{value:e,configurable:!0});import{_ as d}from"./index-2-qFLlQP.js";import{f as p,B as m}from"./widgetPropFilter-CygYoMQt.js";import{bx as g,E as f,c as s,d as i,z as u,k as w,A as b,q as C,u as _,s as k,m as E}from"./vendor-other-CSX7WseZ.js";import"./vendor-primevue-B6rcS73U.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";const P={class:"flex flex-col gap-1"},T=g({__name:"WidgetButton",props:{widget:{}},setup(t){const e=t,l=[...m,"iconClass"],r=f(()=>p(e.widget.options,l)),n=a(()=>{e.widget.callback&&e.widget.callback()},"handleClick");return(o,B)=>(i(),s("div",P,[u(d,E({class:"text-base-foreground w-full border-0 bg-component-node-widget-background p-2","aria-label":o.widget.label,size:"sm",variant:"textonly"},r.value,{onClick:n}),{default:w(()=>[b(_(o.widget.label??o.widget.name)+" ",1),o.widget.options?.iconClass?(i(),s("i",{key:0,class:k(o.widget.options.iconClass)},null,2)):C("",!0)]),_:1},16,["aria-label"])]))}});export{T as default};
//# sourceMappingURL=WidgetButton-Dkge0J8R.js.map
