import{q as l,at as g}from"./index-2-qFLlQP.js";import{a as f}from"./audioUtils-DlA-QHPJ.js";import{_ as h}from"./WidgetSelect.vue_vue_type_script_setup_true_lang-CMg0GtSC.js";import v from"./AudioPreviewPlayer-ybC6cXRM.js";import{bx as w,cM as i,cN as y,E as o,c as V,d as x,z as n}from"./vendor-other-CSX7WseZ.js";import"./vendor-primevue-B6rcS73U.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";import"./widgetPropFilter-CygYoMQt.js";import"./index-_AAd9eTu.js";import"./WidgetLayoutField.vue_vue_type_script_setup_true_lang-Dps42A-g.js";import"./LazyImage.vue_vue_type_script_setup_true_lang-CcI-aYhS.js";import"./WidgetWithControl.vue_vue_type_script_setup_true_lang-COy_p9Eh.js";const N={class:"w-full col-span-2 widget-expands grid grid-cols-[minmax(80px,max-content)_minmax(125px,auto)] gap-y-3 p-3"},C=w({__name:"WidgetAudioUI",props:i({widget:{},readonly:{type:Boolean},nodeId:{}},{modelValue:{},modelModifiers:{}}),emits:i(["update:modelValue"],["update:modelValue"]),setup(a){const t=a,r=y(a,"modelValue"),u=o(()=>!t.nodeId||!l.canvas.graph?null:l.canvas.graph.getNodeById(t.nodeId)),s=o(()=>{const e=u.value;return e?g(e):!1}),m=o(()=>t.widget.value),p=o(()=>{const e=m.value;return e?f(e,"input"):""});return(e,d)=>(x(),V("div",N,[n(h,{modelValue:r.value,"onUpdate:modelValue":d[0]||(d[0]=c=>r.value=c),widget:e.widget,class:"col-span-2"},null,8,["modelValue","widget"]),n(v,{class:"col-span-2","audio-url":p.value,readonly:e.readonly,"hide-when-empty":s.value,"show-options-button":!0},null,8,["audio-url","readonly","hide-when-empty"])]))}});export{C as default};
//# sourceMappingURL=WidgetAudioUI-BZL35TlT.js.map
