import{bx as t,c as a,d as r,e as s,u as l,I as i}from"./vendor-other-CSX7WseZ.js";const n={class:"relative size-full overflow-hidden rounded"},d={class:"flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105"},c={class:"text-base-foreground"},u=["src"],m=t({__name:"MediaAudioTop",props:{asset:{}},setup(p){return(o,e)=>(r(),a("div",n,[s("div",d,[e[1]||(e[1]=s("i",{class:"icon-[lucide--music] text-3xl text-base-foreground"},null,-1)),s("span",c,l(o.$t("assetBrowser.media.audioPlaceholder")),1)]),s("audio",{controls:"",class:"absolute bottom-0 left-0 w-full p-2",src:o.asset.src,onClick:e[0]||(e[0]=i(()=>{},["stop"]))},null,8,u)]))}});export{m as default};
//# sourceMappingURL=MediaAudioTop-Bs8gPEzs.js.map
