import{L as r}from"./vendor-primevue-B6rcS73U.js";import{f as s,S as i}from"./widgetPropFilter-CygYoMQt.js";import{_ as d}from"./WidgetLayoutField.vue_vue_type_script_setup_true_lang-Dps42A-g.js";import{bx as p,cM as u,cN as n,E as f,j as c,d as g,k as w,z as V,by as _,m as b}from"./vendor-other-CSX7WseZ.js";import"./index-2-qFLlQP.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";const N=p({__name:"WidgetToggleSwitch",props:u({widget:{}},{modelValue:{type:Boolean},modelModifiers:{}}),emits:["update:modelValue"],setup(e){const o=n(e,"modelValue"),l=f(()=>s(e.widget.options,i));return(a,t)=>(g(),c(d,{widget:a.widget},{default:w(()=>[V(_(r),b({modelValue:o.value,"onUpdate:modelValue":t[0]||(t[0]=m=>o.value=m)},l.value,{class:"ml-auto block","aria-label":a.widget.name}),null,16,["modelValue","aria-label"])]),_:1},8,["widget"]))}});export{N as default};
//# sourceMappingURL=WidgetToggleSwitch-DwYqmS17.js.map
