[data-v-618d59a6] .p-inputnumber-input{height:1.625rem;margin:1px 0;box-shadow:none}[data-v-989ee2f9] .p-inputnumber-button.p-disabled .pi,[data-v-989ee2f9] .p-inputnumber-button.p-disabled .p-icon{color:var(--color-node-icon-disabled)!important}
