import{bx as m,cM as f,cN as g,E as r,ec as w,j as c,d as C,k as y,z as P,e as V,by as o,m as b,I as s,u as v,s as B}from"./vendor-other-CSX7WseZ.js";import{a9 as I,B as M}from"./vendor-primevue-B6rcS73U.js";import{c as d}from"./index-2-qFLlQP.js";import{f as N,I as h}from"./widgetPropFilter-CygYoMQt.js";import{W as k}from"./index-_AAd9eTu.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";const x=["for"],O=m({__name:"WidgetTextarea",props:f({widget:{},placeholder:{default:""}},{modelValue:{default:""},modelModifiers:{}}),emits:["update:modelValue"],setup(t){const l=g(t,"modelValue"),n=r(()=>N(t.widget.options,h)),u=r(()=>t.widget.label||t.widget.name),i=w();return(a,e)=>(C(),c(o(M),{variant:"in",class:B(o(d)("rounded-lg space-y-1 focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all",a.widget.borderStyle))},{default:y(()=>[P(o(I),b(n.value,{id:o(i),modelValue:l.value,"onUpdate:modelValue":e[0]||(e[0]=p=>l.value=p),class:o(d)(o(k),"size-full text-xs resize-none"),placeholder:a.placeholder,readonly:a.widget.options?.read_only,disabled:a.widget.options?.read_only,fluid:"","data-capture-wheel":"true",onPointerdownCapture:e[1]||(e[1]=s(()=>{},["stop"])),onPointermoveCapture:e[2]||(e[2]=s(()=>{},["stop"])),onPointerupCapture:e[3]||(e[3]=s(()=>{},["stop"])),onContextmenuCapture:e[4]||(e[4]=s(()=>{},["stop"]))}),null,16,["id","modelValue","class","placeholder","readonly","disabled"]),V("label",{for:o(i)},v(u.value),9,x)]),_:1},8,["class"]))}});export{O as default};
//# sourceMappingURL=WidgetTextarea-CZnqW4e_.js.map
