import{du as l}from"./index-2-qFLlQP.js";import{bx as n,E as t,c as m,d as c,u as i}from"./vendor-other-CSX7WseZ.js";const r=["title"],_=n({__name:"MediaTitle",props:{fileName:{}},setup(a){const e=a,o=t(()=>e.fileName),s=t(()=>l(e.fileName));return(p,u)=>(c(),m("h3",{class:"m-0 line-clamp-1 text-sm font-bold text-base-foreground",title:o.value},i(s.value),9,r))}});export{_};
//# sourceMappingURL=MediaTitle.vue_vue_type_script_setup_true_lang-C59zAxW0.js.map
