import{aR as o}from"./index-2-qFLlQP.js";import"./vendor-primevue-B6rcS73U.js";import"./vendor-other-CSX7WseZ.js";import"./vendor-vue-CXt3ZZQ3.js";import"./vendor-xterm-CWYFmgbN.js";import"./vendor-three-BKWXAgVe.js";import"./vendor-tiptap-BkFTmTb3.js";export{o as default};
//# sourceMappingURL=WidgetLegacy-BWDBwsli.js.map
